# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-18 15:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Command',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=200)),
                ('name', models.CharField(max_length=200)),
                ('subject', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='actions', to='visaweb.Asset')),
            ],
        ),
        migrations.AddField(
            model_name='property',
            name='getter_command',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='getter_command', to='visaweb.Command'),
        ),
        migrations.AddField(
            model_name='property',
            name='setter_command',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='setter_command', to='visaweb.Command'),
        ),
    ]
